@@ -87,7 +87,6 @@ OC.L10N.register(
     "Load more" : "さらに読み込む",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "カード \"%s\"(\"%s\"に所属)が%sによってあなたに割り当てられました。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} さんが、{deck-board} で、あなたにカード「{deck-card}」を割り当てました。",
-    "The card \"%s\" on \"%s\" has reached its due date." : "カード \"%s\"(\"%s\"に所属)は期日に達しました。",
     "The card {deck-card} on {deck-board} has reached its due date." : "{deck-board}上のカード「{deck-card}」は、期日を迎えました。",
     "%s has mentioned you in a comment on \"%s\"." : "%sさんは \"%s\"へのコメントであなたについて言及しました。",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} さんが 「{deck-card}」のコメント内であなたについて言及しました。",
@@ -167,6 +166,29 @@ OC.L10N.register(
     "Show card cover images" : "カードの画像を表示する",
     "Open details" : "詳細を開く",
     "Details" : "詳細",
+    "Deck settings" : "デック設定",
+    "General" : "一般",
+    "Use bigger card view" : "大きなカードビューを使用する",
+    "Appearance" : "表示",
+    "Show card ID badge" : "カードIDバジを表示",
+    "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
+    "Limit board creation to some groups" : "ボード作成は一部のグループに制限する",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "これらのグループ以外のユーザーは、独自のボードを作成することはできませんが、共有されているボードで作業することはできます。",
+    "Board actions" : "ボードアクション",
+    "Scroll sideways" : "横にスクロール",
+    "Navigate between cards" : "カード間を移動する",
+    "Close card details" : "カードの詳細を閉じる",
+    "Search" : "検索",
+    "Show card filters" : "カードフィルターを表示",
+    "Clear card filters" : "カードフィルターを削除",
+    "Show those shortcuts" : "これらのショートカットを表示する",
+    "Card actions" : "カードアクション",
+    "Open card details" : "カードの詳細を開く",
+    "Edit the card title" : "カードタイトルを編集する",
+    "Assign yourself to the current card" : "カードを自分に割り当てる",
+    "Archive/unarchive the current card" : "現在のカードをアーカイブ/アーカイブ解除",
+    "Mark card as completed/not completed" : "カードを完了/未完了にマークする",
+    "Open card menu" : "カードメニューを開く",
     "Currently present people" : "現在出席している人々",
     "Loading board" : "ボードを読み込み中",
     "Board not found" : "ボードが見つかりません",
@@ -233,7 +255,6 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
     "The comment cannot be empty." : "コメントを空にすることはできません。",
     "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
-    "Save" : "保存",
     "Created:" : "作成:",
     "In reply to" : "返信",
     "Cancel reply" : "返信をキャンセル",
@@ -274,6 +295,7 @@ OC.L10N.register(
     "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
     "Todo items" : "Todo項目",
     "Edit card title" : "カードタイトルを編集する",
+    "Open link" : "リンクを開く",
     "Card deleted" : "カードが削除されました",
     "Edit title" : "タイトルを編集",
     "Assign to me" : "自分に割り当てる",
@@ -281,41 +303,9 @@ OC.L10N.register(
     "Mark as not done" : "未完成のマーク",
     "Delete card" : "カードを削除する",
     "seconds ago" : "数秒前",
-    "Keyboard shortcuts" : "キーボードショートカット",
-    "Boost your productivity using Deck with keyboard shortcuts." : "キーボードショートカットを使って、あなたのDeckの生産性を向上させましょう。",
-    "Board actions" : "ボードアクション",
-    "Keyboard shortcut" : "キーボードショートカット",
-    "Action" : "アクション",
-    "Shift" : "Shift",
-    "Scroll" : "スクロール",
-    "Scroll sideways" : "横にスクロール",
-    "Navigate between cards" : "カード間を移動する",
-    "Esc" : "Esc",
-    "Close card details" : "カードの詳細を閉じる",
-    "Ctrl" : "Ctrl",
-    "Search" : "検索",
-    "Show card filters" : "カードフィルターを表示",
-    "Clear card filters" : "カードフィルターを削除",
-    "Show help dialog" : "ヘルプダイアログを表示",
-    "Card actions" : "カードアクション",
-    "The following actions can be triggered on the currently highlighted card" : "現在ハイライトされているカードに対して以下のアクションを起こすことができる。",
-    "Enter" : "Enter",
-    "Space" : "スペース",
-    "Open card details" : "カードの詳細を開く",
-    "Edit the card title" : "カードタイトルを編集する",
-    "Assign yourself to the current card" : "カードを自分に割り当てる",
-    "Archive/unarchive the current card" : "現在のカードをアーカイブ/アーカイブ解除",
-    "Mark card as completed/not completed" : "カードを完了/未完了にマークする",
-    "Open card menu" : "カードメニューを開く",
     "All boards" : "すべてのボード",
     "Archived boards" : "アーカイブ済みのボード",
     "Shared with you" : "あなたと共有済み",
-    "Deck settings" : "デック設定",
-    "Use bigger card view" : "大きなカードビューを使用する",
-    "Show card ID badge" : "カードIDバジを表示",
-    "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
-    "Limit board creation to some groups" : "ボード作成は一部のグループに制限する",
-    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "これらのグループ以外のユーザーは、独自のボードを作成することはできませんが、共有されているボードで作業することはできます。",
     "Cancel edit" : "編集をキャンセル",
     "Board {0} deleted" : "ボード {0} 削除済み",
     "All cards" : "すべてのカード",
@@ -324,6 +314,7 @@ OC.L10N.register(
     "An error occurred" : "エラーが発生しました",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "ボード{title}を削除しますか? これにより、アーカイブされたカードを含むこのボードのすべてのデータが削除されます。",
     "Delete the board?" : "ボードを削除しますか？",
+    "Leave" : "出る",
     "Board details" : "ボードの詳細",
     "Edit board" : "ボードを編集",
     "Clone board" : "ボードを複製",
@@ -342,9 +333,6 @@ OC.L10N.register(
     "Export as CSV" : "CSV にエクスポート",
     "Export" : "エクスポート",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
-    "No due" : "日付なし",
     "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
     "No results found" : "結果が見つかりません",
     "Deck board {name}\n* Last modified on {lastMod}" : "デッキボード{name}\n最終更新日：{lastMod}",
@@ -379,11 +367,27 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
     "Share" : "共有",
     "Personal" : "個人",
+    "The card \"%s\" on \"%s\" has reached its due date." : "カード \"%s\"(\"%s\"に所属)は期日に達しました。",
     "To do" : "To do",
     "Doing" : "行うこと",
     "Example Task 3" : "タスク3の例",
     "Example Task 2" : "タスク2の例",
     "Example Task 1" : "タスク1の例",
-    "Move card to another board" : "カードを他のボードに移動"
+    "Save" : "保存",
+    "Keyboard shortcuts" : "キーボードショートカット",
+    "Boost your productivity using Deck with keyboard shortcuts." : "キーボードショートカットを使って、あなたのDeckの生産性を向上させましょう。",
+    "Keyboard shortcut" : "キーボードショートカット",
+    "Action" : "アクション",
+    "Shift" : "Shift",
+    "Scroll" : "スクロール",
+    "Esc" : "Esc",
+    "Ctrl" : "Ctrl",
+    "Show help dialog" : "ヘルプダイアログを表示",
+    "The following actions can be triggered on the currently highlighted card" : "現在ハイライトされているカードに対して以下のアクションを起こすことができる。",
+    "Enter" : "Enter",
+    "Space" : "スペース",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
+    "No due" : "日付なし"
 },
 "nplurals=1; plural=0;");
