@@ -9,6 +9,9 @@ OC.L10N.register(
     "Cancel" : "Avbryt",
     "Completed" : "Fullført",
     "Details" : "Detaljar",
+    "General" : "Generelt",
+    "Appearance" : "Utsjånad",
+    "Search" : "Søk",
     "Sharing" : "Deling",
     "Tags" : "Emneord",
     "Activity" : "Aktivitet",
@@ -22,21 +25,20 @@ OC.L10N.register(
     "Modified" : "Endra",
     "Created" : "Lagd",
     "Comments" : "Kommentarar",
-    "Save" : "Lagre",
     "Created:" : "Oppretta:",
     "Cancel reply" : "Avbryt svar",
     "Reply" : "Svare",
     "Update" : "Oppdater",
     "Description" : "Skildring",
     "seconds ago" : "sekund sidan",
-    "Keyboard shortcuts" : "Tastatursnarvegar",
-    "Search" : "Søk",
     "Shared with you" : "Shared with you",
     "An error occurred" : "Det oppstod ein feil.",
     "Export" : "Eksporter",
     "Close" : "Lat att",
     "Share" : "Del",
     "Personal" : "Personleg",
+    "Save" : "Lagre",
+    "Keyboard shortcuts" : "Tastatursnarvegar",
     "Today" : "I dag"
 },
 "nplurals=2; plural=(n != 1);");
