@@ -91,7 +91,7 @@ OC.L10N.register(
     "Welcome to Nextcloud Deck!" : "欢迎使用 Nextcloud Deck！",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片  \"%s\" （在 \"%s\" 中）已由%s指派给您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已将卡片 {deck-card}， 其位于 {deck-board} ，分配给了你",
-    "The card \"%s\" on \"%s\" has reached its due date." : "卡片 \"%s\" （在 \"%s\" 中）已到期.",
+    "The card \"%1$s\" on \"%2$s\" has reached its due date." : "“%2$s”上的卡片“%1$s”已到期。",
     "The card {deck-card} on {deck-board} has reached its due date." : "卡片 {deck-card}， 其位于 {deck-board} ，已到期",
     "%s has mentioned you in a comment on \"%s\"." : "%s 在 “%s” 的评论中提到了您。",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的一条评论中提到了你",
@@ -181,6 +181,30 @@ OC.L10N.register(
     "Show card cover images" : "显示卡片封面图片",
     "Open details" : "打开详情",
     "Details" : "详情",
+    "Deck settings" : "看板设置",
+    "General" : "常规",
+    "Use bigger card view" : "使用较大的卡片视图",
+    "Appearance" : "外观",
+    "Show card ID badge" : "显示卡片ID序号",
+    "Show boards in calendar/tasks" : "在日历/任务中显示看板",
+    "Admin settings" : "管理员设置",
+    "Limit board creation to some groups" : "限制某些组可以创建看板",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "这些组之外的用户将无法创建自己的看板，但仍然可以在与他们共享的看板上工作。",
+    "Board actions" : "面板操作",
+    "Scroll sideways" : "侧向滚动",
+    "Navigate between cards" : "在卡片之间导航",
+    "Close card details" : "关闭卡详细信息",
+    "Search" : "搜索",
+    "Show card filters" : "显示卡片过滤器",
+    "Clear card filters" : "清除卡片过滤器",
+    "Show those shortcuts" : "显示快捷键",
+    "Card actions" : "卡片操作",
+    "Open card details" : "打开卡片详细信息",
+    "Edit the card title" : "编辑卡片标题",
+    "Assign yourself to the current card" : "将自己分配给当前卡片",
+    "Archive/unarchive the current card" : "存档/取消存档当前卡片",
+    "Mark card as completed/not completed" : "将卡片标记为已完成/未完成",
+    "Open card menu" : "打开卡片菜单",
     "Currently present people" : "当前在线的人",
     "Loading board" : "正在加载面板",
     "Board not found" : "未找到面板",
@@ -248,7 +272,6 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
     "The comment cannot be empty." : "注释不能为空。",
     "The comment cannot be longer than 1000 characters." : "注释不能超过 1000 个字符。",
-    "Save" : "保存",
     "Created:" : "创建于：",
     "In reply to" : "回复",
     "Cancel reply" : "取消回复",
@@ -298,41 +321,9 @@ OC.L10N.register(
     "Mark as not done" : "标记为未完成",
     "Delete card" : "删除卡片",
     "seconds ago" : "几秒前",
-    "Keyboard shortcuts" : "键盘快捷键",
-    "Boost your productivity using Deck with keyboard shortcuts." : "使用带有键盘快捷键的 Deck 提高您的生产力。",
-    "Board actions" : "面板操作",
-    "Keyboard shortcut" : "键盘快捷键",
-    "Action" : "操作",
-    "Shift" : "Shift",
-    "Scroll" : "滚动",
-    "Scroll sideways" : "侧向滚动",
-    "Navigate between cards" : "在卡片之间导航",
-    "Esc" : "Esc",
-    "Close card details" : "关闭卡详细信息",
-    "Ctrl" : "Ctrl",
-    "Search" : "搜索",
-    "Show card filters" : "显示卡片过滤器",
-    "Clear card filters" : "清除卡片过滤器",
-    "Show help dialog" : "显示帮助对话框",
-    "Card actions" : "卡片操作",
-    "The following actions can be triggered on the currently highlighted card" : "可以在当前突出显示的卡上触发以下操作",
-    "Enter" : "输入",
-    "Space" : "空间",
-    "Open card details" : "打开卡片详细信息",
-    "Edit the card title" : "编辑卡片标题",
-    "Assign yourself to the current card" : "将自己分配给当前卡片",
-    "Archive/unarchive the current card" : "存档/取消存档当前卡片",
-    "Mark card as completed/not completed" : "将卡片标记为已完成/未完成",
-    "Open card menu" : "打开卡片菜单",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared with you" : "收到的共享",
-    "Deck settings" : "看板设置",
-    "Use bigger card view" : "使用较大的卡片视图",
-    "Show card ID badge" : "显示卡片ID序号",
-    "Show boards in calendar/tasks" : "在日历/任务中显示看板",
-    "Limit board creation to some groups" : "限制某些组可以创建看板",
-    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "这些组之外的用户将无法创建自己的看板，但仍然可以在与他们共享的看板上工作。",
     "Cancel edit" : "取消编辑",
     "Save board" : "保存面板",
     "Board {0} deleted" : "面板{0} 被删除",
@@ -342,6 +333,10 @@ OC.L10N.register(
     "An error occurred" : "发生错误",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您确定要删除面板 {title} 吗？这将删除该面板的所有数据，包括已归档卡片。",
     "Delete the board?" : "是否删除面板？",
+    "Are you sure you want to leave the board {title}?" : "是否确定要离开面板 {title}？",
+    "Leave the board?" : "离开面板？",
+    "Leave" : "离开",
+    "Failed to leave the board" : "无法离开面板",
     "Exporting board..." : "正在导出面板…",
     "Board details" : "面板详情",
     "Edit board" : "编辑面板",
@@ -355,6 +350,7 @@ OC.L10N.register(
     "Assigned cards" : "已指派的卡片",
     "No notifications" : "无通知",
     "Delete board" : "删除看板",
+    "Leave board" : "离开面板",
     "Importing board..." : "正在导入面板…",
     "Board imported successfully" : "面板导入成功",
     "Import board" : "导入面板",
@@ -373,9 +369,7 @@ OC.L10N.register(
     "Note: Only the JSON format is supported for importing back into the Deck app." : "注意：只有 JSON 格式才支持导入回 Deck 应用。",
     "Export" : "导出",
     "Loading filtered view" : "正在加载已筛选的视图",
-    "Today" : "今天",
-    "Tomorrow" : "明天",
-    "No due" : "没有到期的",
+    "Search for {searchQuery} in other boards" : "在其他面板中搜索 {searchQuery}",
     "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
     "No results found" : "未找到结果",
     "Deck board {name}\n* Last modified on {lastMod}" : "看板{name}\n* 最后修改于{lastMod}",
@@ -411,11 +405,27 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "将{file}分享给一张看板卡片",
     "Share" : "分享",
     "Personal" : "个人",
+    "The card \"%s\" on \"%s\" has reached its due date." : "卡片 \"%s\" （在 \"%s\" 中）已到期.",
     "To do" : "待办",
     "Doing" : "进行中",
     "Example Task 3" : "示例任务 3",
     "Example Task 2" : "示例任务 2",
     "Example Task 1" : "示例任务 1",
-    "Move card to another board" : "将卡片移到其他面板"
+    "Save" : "保存",
+    "Keyboard shortcuts" : "键盘快捷键",
+    "Boost your productivity using Deck with keyboard shortcuts." : "使用带有键盘快捷键的 Deck 提高您的生产力。",
+    "Keyboard shortcut" : "键盘快捷键",
+    "Action" : "操作",
+    "Shift" : "Shift",
+    "Scroll" : "滚动",
+    "Esc" : "Esc",
+    "Ctrl" : "Ctrl",
+    "Show help dialog" : "显示帮助对话框",
+    "The following actions can be triggered on the currently highlighted card" : "可以在当前突出显示的卡上触发以下操作",
+    "Enter" : "输入",
+    "Space" : "空间",
+    "Today" : "今天",
+    "Tomorrow" : "明天",
+    "No due" : "没有到期的"
 },
 "nplurals=1; plural=0;");
