@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -6,7 +7,9 @@
 
 namespace OCA\Deck\Controller;
 
+use OCA\Deck\NoPermissionException;
 use OCA\Deck\Service\Importer\BoardImportService;
+use OCA\Deck\Service\PermissionService;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\OCSController;
@@ -17,6 +20,7 @@ class BoardImportApiController extends OCSController {
 		string $appName,
 		IRequest $request,
 		private BoardImportService $boardImportService,
+		private PermissionService $permissionService,
 		private string $userId,
 	) {
 		parent::__construct($appName, $request);
@@ -28,6 +32,9 @@ class BoardImportApiController extends OCSController {
 	 * @NoCSRFRequired
 	 */
 	public function import(string $system, array $config, array $data): DataResponse {
+		if (!$this->permissionService->canCreate()) {
+			throw new NoPermissionException('Creating boards has been disabled for your account.');
+		}
 		$this->boardImportService->setSystem($system);
 		$config = json_decode(json_encode($config));
 		$config->owner = $this->userId;
