@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -10,8 +11,10 @@ namespace OCA\Deck\Cron;
 use OCA\Deck\Db\AttachmentMapper;
 use OCA\Deck\Db\BoardMapper;
 use OCA\Deck\Db\CardMapper;
+use OCA\Deck\Db\StackMapper;
 use OCA\Deck\InvalidAttachmentType;
 use OCA\Deck\Service\AttachmentService;
+use OCA\Deck\Sharing\DeckShareProvider;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\BackgroundJob\IJob;
 use OCP\BackgroundJob\TimedJob;
@@ -26,13 +29,27 @@ class DeleteCron extends TimedJob {
 	private $attachmentService;
 	/** @var AttachmentMapper */
 	private $attachmentMapper;
+	/** @var StackMapper */
+	private $stackMapper;
+	/** @var DeckShareProvider */
+	private $deckShareProvider;
 
-	public function __construct(ITimeFactory $time, BoardMapper $boardMapper, CardMapper $cardMapper, AttachmentService $attachmentService, AttachmentMapper $attachmentMapper) {
+	public function __construct(
+		ITimeFactory $time,
+		BoardMapper $boardMapper,
+		CardMapper $cardMapper,
+		AttachmentService $attachmentService,
+		AttachmentMapper $attachmentMapper,
+		StackMapper $stackMapper,
+		DeckShareProvider $deckShareProvider,
+	) {
 		parent::__construct($time);
 		$this->boardMapper = $boardMapper;
 		$this->cardMapper = $cardMapper;
 		$this->attachmentService = $attachmentService;
 		$this->attachmentMapper = $attachmentMapper;
+		$this->stackMapper = $stackMapper;
+		$this->deckShareProvider = $deckShareProvider;
 
 		$this->setInterval(60 * 60 * 24);
 		$this->setTimeSensitivity(IJob::TIME_INSENSITIVE);
@@ -64,5 +81,16 @@ class DeleteCron extends TimedJob {
 			}
 			$this->attachmentMapper->delete($attachment);
 		}
+
+		// Delete orphaned attachment shares
+		$shares = $this->deckShareProvider->getOrphanedAttachmentShares();
+		foreach ($shares as $share) {
+			$this->deckShareProvider->delete($share);
+		}
+
+		$stacks = $this->stackMapper->findToDelete();
+		foreach ($stacks as $stack) {
+			$this->stackMapper->delete($stack);
+		}
 	}
 }
