@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -38,7 +39,7 @@ class LiveUpdateListener implements IEventListener {
 		IRequest $request,
 		LoggerInterface $logger,
 		SessionService $sessionService,
-		StackMapper $stackMapper
+		StackMapper $stackMapper,
 	) {
 		try {
 			$this->queue = $container->get(IQueue::class);
