@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -58,7 +59,7 @@ class AttachmentService {
 		$userId,
 		IL10N $l10n,
 		ActivityManager $activityManager,
-		AttachmentServiceValidator $attachmentServiceValidator
+		AttachmentServiceValidator $attachmentServiceValidator,
 	) {
 		$this->attachmentMapper = $attachmentMapper;
 		$this->cardMapper = $cardMapper;
