@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -28,6 +29,7 @@ use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
 use OCA\Deck\StatusException;
 use OCA\Deck\Validators\CardServiceValidator;
+use OCP\Collaboration\Reference\IReferenceManager;
 use OCP\Comments\ICommentsManager;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IRequest;
@@ -36,73 +38,34 @@ use OCP\IUserManager;
 use Psr\Log\LoggerInterface;
 
 class CardService {
-	private CardMapper $cardMapper;
-	private StackMapper $stackMapper;
-	private BoardMapper $boardMapper;
-	private LabelMapper $labelMapper;
-	private LabelService $labelService;
-	private PermissionService $permissionService;
-	private BoardService $boardService;
-	private NotificationHelper $notificationHelper;
-	private AssignmentMapper $assignedUsersMapper;
-	private AttachmentService $attachmentService;
-	private ?string $currentUser;
-	private ActivityManager $activityManager;
-	private ICommentsManager $commentsManager;
-	private ChangeHelper $changeHelper;
-	private IEventDispatcher $eventDispatcher;
-	private IUserManager $userManager;
-	private IURLGenerator $urlGenerator;
-	private LoggerInterface $logger;
-	private IRequest $request;
-	private CardServiceValidator $cardServiceValidator;
-
 	public function __construct(
-		CardMapper $cardMapper,
-		StackMapper $stackMapper,
-		BoardMapper $boardMapper,
-		LabelMapper $labelMapper,
-		LabelService $labelService,
-		PermissionService $permissionService,
-		BoardService $boardService,
-		NotificationHelper $notificationHelper,
-		AssignmentMapper $assignedUsersMapper,
-		AttachmentService $attachmentService,
-		ActivityManager $activityManager,
-		ICommentsManager $commentsManager,
-		IUserManager $userManager,
-		ChangeHelper $changeHelper,
-		IEventDispatcher $eventDispatcher,
-		IURLGenerator $urlGenerator,
-		LoggerInterface $logger,
-		IRequest $request,
-		CardServiceValidator $cardServiceValidator,
-		?string $userId
+		private CardMapper $cardMapper,
+		private StackMapper $stackMapper,
+		private BoardMapper $boardMapper,
+		private LabelMapper $labelMapper,
+		private LabelService $labelService,
+		private PermissionService $permissionService,
+		private BoardService $boardService,
+		private NotificationHelper $notificationHelper,
+		private AssignmentMapper $assignedUsersMapper,
+		private AttachmentService $attachmentService,
+		private ActivityManager $activityManager,
+		private ICommentsManager $commentsManager,
+		private IUserManager $userManager,
+		private ChangeHelper $changeHelper,
+		private IEventDispatcher $eventDispatcher,
+		private IURLGenerator $urlGenerator,
+		private LoggerInterface $logger,
+		private IRequest $request,
+		private CardServiceValidator $cardServiceValidator,
+		private AssignmentService $assignmentService,
+		private IReferenceManager $referenceManager,
+		private ?string $userId,
 	) {
-		$this->cardMapper = $cardMapper;
-		$this->stackMapper = $stackMapper;
-		$this->boardMapper = $boardMapper;
-		$this->labelMapper = $labelMapper;
-		$this->labelService = $labelService;
-		$this->permissionService = $permissionService;
-		$this->boardService = $boardService;
-		$this->notificationHelper = $notificationHelper;
-		$this->assignedUsersMapper = $assignedUsersMapper;
-		$this->attachmentService = $attachmentService;
-		$this->activityManager = $activityManager;
-		$this->commentsManager = $commentsManager;
-		$this->userManager = $userManager;
-		$this->changeHelper = $changeHelper;
-		$this->eventDispatcher = $eventDispatcher;
-		$this->currentUser = $userId;
-		$this->urlGenerator = $urlGenerator;
-		$this->logger = $logger;
-		$this->request = $request;
-		$this->cardServiceValidator = $cardServiceValidator;
 	}
 
 	public function enrichCards($cards) {
-		$user = $this->userManager->get($this->currentUser);
+		$user = $this->userManager->get($this->userId);
 
 		$cardIds = array_map(function (Card $card) use ($user) {
 			// Everything done in here might be heavy as it is executed for every card
@@ -142,11 +105,21 @@ class CardService {
 
 		return array_map(
 			function (Card $card): CardDetails {
-				return new CardDetails($card);
+				$cardDetails = new CardDetails($card);
+
+				$references = $this->referenceManager->extractReferences($card->getTitle());
+				$reference = array_shift($references);
+				if ($reference) {
+					$referenceData = $this->referenceManager->resolveReference($reference);
+					$cardDetails->setReferenceData($referenceData);
+				}
+
+				return $cardDetails;
 			},
 			$cards
 		);
 	}
+
 	public function fetchDeleted($boardId) {
 		$this->cardServiceValidator->check(compact('boardId'));
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
@@ -186,9 +159,7 @@ class CardService {
 			$this->logger->error('Unable to check permission for a previously obtained board ' . $boardId, ['exception' => $e]);
 			return [];
 		}
-		$cards = $this->cardMapper->findCalendarEntries($boardId);
-		$this->enrichCards($cards);
-		return $cards;
+		return $this->cardMapper->findCalendarEntries($boardId);
 	}
 
 	/**
@@ -226,6 +197,8 @@ class CardService {
 		$this->changeHelper->cardChanged($card->getId(), false);
 		$this->eventDispatcher->dispatchTyped(new CardCreatedEvent($card));
 
+		[$card] = $this->enrichCards([$card]);
+
 		return $card;
 	}
 
@@ -300,7 +273,7 @@ class CardService {
 		}
 
 		$changes = new ChangeSet($card);
-		if ($card->getLastEditor() !== $this->currentUser && $card->getLastEditor() !== null) {
+		if ($card->getLastEditor() !== $this->userId && $card->getLastEditor() !== null) {
 			$this->activityManager->triggerEvent(
 				ActivityManager::DECK_OBJECT_CARD,
 				$card,
@@ -313,7 +286,7 @@ class CardService {
 			);
 
 			$card->setDescriptionPrev($card->getDescription());
-			$card->setLastEditor($this->currentUser);
+			$card->setLastEditor($this->userId);
 		}
 		$card->setTitle($title);
 		$card->setStackId($stackId);
@@ -356,11 +329,11 @@ class CardService {
 		$card = $this->cardMapper->update($card);
 		$oldBoardId = $this->stackMapper->findBoardId($changes->getBefore()->getStackId());
 		$boardId = $this->cardMapper->findBoardId($card->getId());
-		if($boardId !== $oldBoardId) {
+		if ($boardId !== $oldBoardId) {
 			$stack = $this->stackMapper->find($card->getStackId());
 			$board = $this->boardService->find($this->cardMapper->findBoardId($card->getId()));
 			$boardLabels = $board->getLabels() ?? [];
-			foreach($card->getLabels() as $cardLabel) {
+			foreach ($card->getLabels() as $cardLabel) {
 				$this->removeLabel($card->getId(), $cardLabel->getId());
 				$label = $this->labelMapper->find($cardLabel->getId());
 				$filteredLabels = array_values(array_filter($boardLabels, fn ($item) => $item->getTitle() === $label->getTitle()));
@@ -383,13 +356,47 @@ class CardService {
 		if ($resetDuedateNotification) {
 			$this->notificationHelper->markDuedateAsRead($card);
 		}
-		$this->changeHelper->cardChanged($card->getId(), true);
+		$this->changeHelper->cardChanged($card->getId());
 
 		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
+		[$card] = $this->enrichCards([$card]);
+
 		return $card;
 	}
 
+	public function cloneCard(int $id, ?int $targetStackId = null):Card {
+		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_READ);
+		$originCard = $this->cardMapper->find($id);
+		if ($targetStackId === null) {
+			$targetStackId = $originCard->getStackId();
+		}
+		$this->permissionService->checkPermission($this->stackMapper, $targetStackId, Acl::PERMISSION_EDIT);
+		$newCard = $this->create($originCard->getTitle(), $targetStackId, $originCard->getType(), $originCard->getOrder(), $originCard->getOwner());
+		$boardId = $this->stackMapper->findBoardId($targetStackId);
+		foreach ($this->labelMapper->findAssignedLabelsForCard($id) as $label) {
+			if ($boardId != $this->stackMapper->findBoardId($originCard->getStackId())) {
+				try {
+					$label = $this->labelService->cloneLabelIfNotExists($label->getId(), $boardId);
+				} catch (NoPermissionException $e) {
+					break;
+				}
+			}
+			$this->assignLabel($newCard->getId(), $label->getId());
+		}
+		foreach ($this->assignedUsersMapper->findAll($id) as $assignement) {
+			try {
+				$this->permissionService->checkPermission($this->cardMapper, $newCard->getId(), Acl::PERMISSION_READ, $assignement->getParticipant());
+			} catch (NoPermissionException $e) {
+				continue;
+			}
+			$this->assignmentService->assignUser($newCard->getId(), $assignement->getParticipant());
+		}
+		$newCard->setDescription($originCard->getDescription());
+		$card = $this->enrichCards([$this->cardMapper->update($newCard)]);
+		return $card[0];
+	}
+
 	/**
 	 * @param $id
 	 * @param $title
@@ -411,11 +418,12 @@ class CardService {
 		if ($card->getArchived()) {
 			throw new StatusException('Operation not allowed. This card is archived.');
 		}
+		$changes = new ChangeSet($card);
 		$card->setTitle($title);
 		$this->changeHelper->cardChanged($card->getId(), false);
 		$update = $this->cardMapper->update($card);
 
-		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
 		return $update;
 	}
@@ -431,10 +439,9 @@ class CardService {
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function reorder($id, $stackId, $order) {
+	public function reorder(int $id, int $stackId, int $order) {
 		$this->cardServiceValidator->check(compact('id', 'stackId', 'order'));
 
-
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		$this->permissionService->checkPermission($this->stackMapper, $stackId, Acl::PERMISSION_EDIT);
 
@@ -452,30 +459,30 @@ class CardService {
 		$changes->setAfter($card);
 		$this->activityManager->triggerUpdateEvents(ActivityManager::DECK_OBJECT_CARD, $changes, ActivityManager::SUBJECT_CARD_UPDATE);
 
-		$cards = $this->cardMapper->findAll($stackId);
+		$cardsToReorder = $this->cardMapper->findAll($stackId);
 		$result = [];
 		$i = 0;
-		foreach ($cards as $card) {
-			if ($card->getArchived()) {
+		foreach ($cardsToReorder as $cardToReorder) {
+			if ($cardToReorder->getArchived()) {
 				throw new StatusException('Operation not allowed. This card is archived.');
 			}
-			if ($card->id === $id) {
-				$card->setOrder($order);
-				$card->setLastModified(time());
+			if ($cardToReorder->id === $id) {
+				$cardToReorder->setOrder($order);
+				$cardToReorder->setLastModified(time());
 			}
 
 			if ($i === $order) {
 				$i++;
 			}
 
-			if ($card->id !== $id) {
-				$card->setOrder($i++);
+			if ($cardToReorder->id !== $id) {
+				$cardToReorder->setOrder($i++);
 			}
-			$this->cardMapper->update($card);
-			$result[$card->getOrder()] = $card;
+			$this->cardMapper->update($cardToReorder);
+			$result[$cardToReorder->getOrder()] = $cardToReorder;
 		}
 		$this->changeHelper->cardChanged($id, false);
-		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
 		return array_values($result);
 	}
@@ -492,19 +499,19 @@ class CardService {
 	public function archive($id) {
 		$this->cardServiceValidator->check(compact('id'));
 
-
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $id)) {
 			throw new StatusException('Operation not allowed. This board is archived.');
 		}
 		$card = $this->cardMapper->find($id);
+		$changes = new ChangeSet($card);
 		$card->setArchived(true);
 		$newCard = $this->cardMapper->update($card);
 		$this->notificationHelper->markDuedateAsRead($card);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $newCard, ActivityManager::SUBJECT_CARD_UPDATE_ARCHIVE);
 		$this->changeHelper->cardChanged($id, false);
 
-		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
 		return $newCard;
 	}
@@ -527,12 +534,13 @@ class CardService {
 			throw new StatusException('Operation not allowed. This board is archived.');
 		}
 		$card = $this->cardMapper->find($id);
+		$changes = new ChangeSet($card);
 		$card->setArchived(false);
 		$newCard = $this->cardMapper->update($card);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $newCard, ActivityManager::SUBJECT_CARD_UPDATE_UNARCHIVE);
 		$this->changeHelper->cardChanged($id, false);
 
-		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
 		return $newCard;
 	}
@@ -552,13 +560,14 @@ class CardService {
 			throw new StatusException('Operation not allowed. This board is archived.');
 		}
 		$card = $this->cardMapper->find($id);
+		$changes = new ChangeSet($card);
 		$card->setDone(new \DateTime());
 		$newCard = $this->cardMapper->update($card);
 		$this->notificationHelper->markDuedateAsRead($card);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $newCard, ActivityManager::SUBJECT_CARD_UPDATE_DONE);
 		$this->changeHelper->cardChanged($id, false);
 
-		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
 		return $newCard;
 	}
@@ -578,12 +587,13 @@ class CardService {
 			throw new StatusException('Operation not allowed. This board is archived.');
 		}
 		$card = $this->cardMapper->find($id);
+		$changes = new ChangeSet($card);
 		$card->setDone(null);
 		$newCard = $this->cardMapper->update($card);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $newCard, ActivityManager::SUBJECT_CARD_UPDATE_UNDONE);
 		$this->changeHelper->cardChanged($id, false);
 
-		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
 		return $newCard;
 	}
@@ -600,8 +610,9 @@ class CardService {
 	public function assignLabel($cardId, $labelId) {
 		$this->cardServiceValidator->check(compact('cardId', 'labelId'));
 
-
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_EDIT);
+		$this->permissionService->checkPermission($this->labelMapper, $labelId, Acl::PERMISSION_READ);
+
 		if ($this->boardService->isArchived($this->cardMapper, $cardId)) {
 			throw new StatusException('Operation not allowed. This board is archived.');
 		}
@@ -610,6 +621,9 @@ class CardService {
 			throw new StatusException('Operation not allowed. This card is archived.');
 		}
 		$label = $this->labelMapper->find($labelId);
+		if ($label->getBoardId() !== $this->cardMapper->findBoardId($card->getId())) {
+			throw new StatusException('Operation not allowed. Label does not exist.');
+		}
 		$this->cardMapper->assignLabel($cardId, $labelId);
 		$this->changeHelper->cardChanged($cardId);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $card, ActivityManager::SUBJECT_LABEL_ASSIGN, ['label' => $label]);
@@ -631,6 +645,8 @@ class CardService {
 
 
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_EDIT);
+		$this->permissionService->checkPermission($this->labelMapper, $labelId, Acl::PERMISSION_READ);
+
 		if ($this->boardService->isArchived($this->cardMapper, $cardId)) {
 			throw new StatusException('Operation not allowed. This board is archived.');
 		}
@@ -646,13 +662,13 @@ class CardService {
 		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
 	}
 
-	public function getCardUrl($cardId) {
+	public function getCardUrl(int $cardId): string {
 		$boardId = $this->cardMapper->findBoardId($cardId);
 
-		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . "#/board/$boardId/card/$cardId";
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.indexCard', ['boardId' => $boardId, 'cardId' => $cardId]);
 	}
 
-	public function getRedirectUrlForCard($cardId) {
-		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . "card/$cardId";
+	public function getRedirectUrlForCard(int $cardId): string {
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.redirectToCard', ['cardId' => $cardId]);
 	}
 }
